Zákaznícky servis - Nahodsa.sk
Author: Nahodsa.sk
Description: Kontakty pre zákazníkov eshopu Nahodsa.sk
Keywords: zákaznícky servis, kontakt, telefon, email, adresa, Nahodsa.sk

Športová obuv a oblečenie - Nahodsa.sk

- Prihlásiť
- Pozrieť košík
- Telefonická objednávka
- Kontakt
- Poradíme vám
- Ako nakupovať

Pon - Pia 9:00 - 17:000948 31 30 28
Search:
0 produktov / 0,00 €

# Zákaznícky servis

# ZAVOLAJTE NÁM

Máte otázku ohľadom objednávky, vrátenia tovaru ,platby alebo iný problém ?

Ak preferujete telefonicky kontakt sme pripravený Vám pomôcť na telefonickej linke 0948 31 30 28 od pondelka do piatku, v čase od 09:00 do 17:00.

# NAPIŠTE NÁM :

Reklamácie : reklamacie@nahodsa.sk

- Ak potrebujete pomoct pri reklamácii alebo zistit stav Vašej reklamácie .

Objednávky : objednavky@nahodsa.sk

- Informácie o stave Vašich objednávok .

Informácie : info@nahodsa.sk

- Radi privítame Vaše pripomienky alebo návrhy na vylepšnie nášho internetového obchodu.

Marketing : manager@nahodsa.sk

- V prípade ponuky reklamy alebo možnej spolupráce nás neváhajte kontaktovať na tomto emaile.

Distribucia : sales@nahodsa.sk

- V prípade veľkoobchodnej spolupráce nás neváhajte kontaktovať. Email určený výhradne distribútorom.

# VRÁTENIE TOVARU :

Vrátený tovar zasielajte na nížšie uvedenú adresu :

Sports trade s.r.o.
Priemyselná 45
071 01 Michalovce
Slovensko

< Späť

- MUŽI
- ŽENY
- DETI
- KONTAKT
- REGISTRÁCIA
- AKCIA
- NAJNOVŠIE
- NAJPREDÁVANEJŠIE
- SKLADOM
- Obchodné podmienky

All rights reserved nahodsa.sk © 2011 - 2013
Ďalšie naše projekty: nahodse.cz | outletuj.sk | outletuj.cz | Nahodsa.sk - BLOG